pub enum HERStrategy {
Final,
Future {
k: usize,
},
Episode,
}Expand description
HER goal relabeling strategy.
Variants
Final
Replace goal with the final state achieved in the episode.
Future
Replace goal with a future state sampled uniformly from the remainder.
Episode
Replace goal with a random state from the episode.