pub struct RandomShift {
pub pad: usize,
}Expand description
DrQ-v2 random shift augmentation.
Pads the image with zeros, then randomly crops back to original size.
Effectively translates the image by up to pad pixels in each direction.
Fields
pad: usizeTrait Implementations
Sourceimpl ImageAugmentation for RandomShift
impl ImageAugmentation for RandomShift