pub struct RunningStatsVec { /* private fields */ }Expand description
Per-dimension online running statistics using Welford’s algorithm.
Maintains independent mean/variance accumulators for each dimension,
enabling proper per-feature observation normalization as in SB3’s
RunningMeanStd.
Implementations
Sourceimpl RunningStatsVec
impl RunningStatsVec
Sourcepub fn new(dim: usize) -> Self
pub fn new(dim: usize) -> Self
Create a new accumulator for vectors of the given dimensionality.
Sourcepub fn update(&mut self, values: &[f64])
pub fn update(&mut self, values: &[f64])
Update with a single sample of length dim (Welford per dimension).
Panics
Panics if values.len() != dim.
Sourcepub fn batch_update(&mut self, data: &[f64], batch_size: usize)
pub fn batch_update(&mut self, data: &[f64], batch_size: usize)
Update with a flat batch of batch_size samples, each of dim dimensions.
data must have length batch_size * dim, laid out as
[sample0_dim0, sample0_dim1, ..., sample1_dim0, ...].
Panics
Panics if data.len() != batch_size * dim.
Sourcepub fn normalize(&self, values: &[f64]) -> Vec<f64>
pub fn normalize(&self, values: &[f64]) -> Vec<f64>
Normalize a single sample: (values - mean) / max(std, 1e-8) per dimension.
Panics
Panics if values.len() != dim.