pub struct RewardContext<'a> {
pub dones: &'a [f64],
pub gamma: f64,
pub extras: &'a [(&'a str, &'a [f64])],
}Expand description
Context passed to reward transforms for access to transition metadata.
Fields
dones: &'a [f64]gamma: f64extras: &'a [(&'a str, &'a [f64])]Arbitrary f64 slices keyed by name, for potential values, goal distances, etc.